#
# spec file for package krunner
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libKF5Runner5
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%define qt5_version 5.15.2
%bcond_without released
Name:           krunner
Version:        5.116.0
Release:        1.2
Summary:        KDE Framework for providing different actions given a string query
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{name}-%{version}.tar.xz
%if %{with released}
Source1:        %{name}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  extra-cmake-modules >= %{_kf5_version}
BuildRequires:  fdupes
BuildRequires:  cmake(KF5Activities) >= %{_kf5_version}
BuildRequires:  cmake(KF5Config) >= %{_kf5_version}
BuildRequires:  cmake(KF5CoreAddons) >= %{_kf5_version}
BuildRequires:  cmake(KF5I18n) >= %{_kf5_version}
BuildRequires:  cmake(KF5KIO) >= %{_kf5_version}
BuildRequires:  cmake(KF5Plasma) >= %{_kf5_version}
BuildRequires:  cmake(KF5Service) >= %{_kf5_version}
BuildRequires:  cmake(KF5ThreadWeaver) >= %{_kf5_version}
BuildRequires:  cmake(Qt5Gui) >= %{qt5_version}
BuildRequires:  cmake(Qt5Quick) >= %{qt5_version}
BuildRequires:  cmake(Qt5Test) >= %{qt5_version}

%description
KDE Framework for providing different actions given a string query.

%package -n %{lname}
Summary:        KDE Framework for providing different actions given a string query

%description -n %{lname}
KDE Framework for providing different actions given a string query.

%package devel
Summary:        KDE Framework for providing different actions given a string query
Requires:       %{lname} = %{version}
Requires:       cmake(KF5Plasma) >= %{_kf5_version}
Requires:       cmake(Qt5Core) >= %{qt5_version}
Conflicts:      kapptemplate <= 16.03.80

%description devel
Files needed for developing custom runners or frontends.

%prep
%autosetup -p1

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build
%fdupes %{buildroot}

%ldconfig_scriptlets -n %{lname}

%files -n %{lname}
%license LICENSES/*
%{_kf5_libdir}/libKF5Runner.so.*
%{_kf5_qmldir}/
%{_kf5_servicetypesdir}/plasma-runner.desktop
%{_kf5_debugdir}/*.categories
%{_kf5_debugdir}/*.renamecategories

%files devel
%{_kf5_libdir}/libKF5Runner.so
%{_kf5_libdir}/cmake/KF5Runner/
%{_kf5_includedir}/KRunner/
%{_kf5_mkspecsdir}/qt_KRunner.pri
%{_kf5_sharedir}/kdevappwizard/
%{_kf5_dbusinterfacesdir}/kf5_org.kde.krunner1.xml

%changelog
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.116.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.116.0
- Changes since 5.115.0:
  * Add default arg to AbstractRunner QVariantList constructor
* Thu Feb  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.115.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.115.0
- No code change since 5.114.0
* Sat Jan 13 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.114.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.114.0
- Changes since 5.113.0:
  * DBusRunner: Use /runner as default for X-Plasma-DBusRunner-Path property
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.113.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.113.0
- Changes since 5.112.0:
  * Deprecate old QueryMatch::setType which will be removed in KF6
  * Backport KF6 API to set categoryRelevance for QueryMatch
* Mon Nov  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.112.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.112.0
- No code change since 5.111.0
* Mon Oct  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.111.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.111.0
- Changes since 5.110.0:
  * runnerpython: Fix install script paths to desktop files
* Wed Sep  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.110.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.110.0
- No code change since 5.109.0
* Tue Aug  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.109.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.109.0
- Changes since 5.108.0:
  * runnerpython cgit.kde.org does not exist
  * Add explicit moc includes to sources for moc-covered headers
* Mon Jul  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.108.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.108.0
- Changes since 5.107.0:
  * Remove qt6 CI builds
* Mon Jun  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.107.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.107.0
- No code change since 5.106.0
* Sat May  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.106.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.106.0
- Changes since 5.105.0:
  * Backport new API for RunnerSyntax, deprecated old API
  * Repair binary compatibility for RunnerSyntax
* Sat Apr  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.105.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.105.0
- No code change since 5.104.0
* Mon Mar  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.104.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.104.0
- Changes since 5.103.0:
  * KF5KRunnerMacros: Add compat code and warning for in KF6 renamed configure_krunner_test macro
* Wed Feb  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.103.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.103.0
- No code change since 5.102.0
* Thu Jan 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.102.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.102.0
- Changes since 5.101.0:
  * AbstractRunnerTest: Provider better error message if plugin could not be found
  * AbstractRunnerTest: Use QFileInfo::completeBaseName rather than QFileInfo::baseName
* Tue Dec  6 2022 Christophe Marin <christophe@krop.fr>
- Update to 5.101.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.101.0
- Changes since 5.100.0:
  * QueryMatch: Avoid unneeded QVariant conversion to string when setting data
  * cppcheck: Do not shadow outer functions with local variables
  * cppcheck: Make constructors explicit
  * Fix crash when deleting RunnerManager while jobs are running (kde#448825)
* Tue Nov  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.100.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.100.0
- Changes since 5.99.0:
  * Ignore "templates" folder for cppcheck CI
  * runnermanager: only emit `queryFinished` when previous jobs are still running
* Sat Oct  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.99.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.99.0
- Changes since 5.98.0:
  * QueryMatch: Make long docstrings for enum values more readable
  * Deprecate QueryMatch::MatchType::InformationalMatch
  * Runner templates: fix install location
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.98.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.98.0
- Changes since 5.97.0:
  * Add FreeBSD Qt6 CI support
  * Fix renaming of plugin ID when converting DBus runner metadata files (kde#456562)
* Sun Aug  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.97.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.97.0
- Changes since 5.96.0:
  * Add note about alternative to Plasma::RunnerContext::setSingleRunnerQueryMode
  * Fix TODO being shown in generated docs
  * templates/runnerpython: Add hint for multiline property
  * Fix Qt6 build
* Sun Jul  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.96.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.96.0
- Changes since 5.95.0:
  * Move include outside #ifdef as it's necessary
  * Don't duplicate headers between cpp/.h files
  * Bump deprecation KF version in ecm_set_disabled_deprecation_versions
  * Use cmakedefine01
* Fri Jun 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.95.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.95.0
- Changes since 5.94.0:
  * autotests: Clean up unneeded includes
  * RunnerContext: Call addMatch(QList<QueryMatch) internally when addMatch(QueryMatch) is called
  * RunnerContext::addMatch: Fix broken handling of relevance for often launched entries
  * Fix Qt6 build with KF 5.94 deprecation level
  * Port away from deprecated KPluginMetaData::fromDesktopFile
  * Bump version for disabled KF deprecations
  * port to standard C++ smart pointers where possible
  * DBusRunner: Avoid double lookup of match properties
  * DBusRunner: Add multiline value to property map of RemoteMatch
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.94.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.94.0
- Changes since 5.93.0:
  * Require unit tests to pass on CI
  * Fix Qt6 build unit tests
  * Fix FreeBSD runnercontexttest on GitlabCI
  * Make Qt::Gui dependency for deprecation free builds internal
  * Deprecate public KConfigGroup include of AbstractRunner class
* Sun Apr  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.93.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.93.0
- Changes since 5.92.0:
  * Fix testremoterunner not registering object/service when building
    without assertions
  * Mark qrc file as non-copyrightable
  * Remove upper-limits for RunnerManagerTest's timeouts
  * autotests: urgh, this test is really timing dependent, and fails
    if CI is slow
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.92.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.92.0
- Changes since 5.91.0:
  * Bundle plasma-runner.desktop into a qrc, for CI and Windows
* Sun Feb  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.91.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.91.0
- Changes since 5.90.0:
  * runnermanagerpublictest: Do not load system provided plugins
  * search plugins in kf<version>
  * Put aliased classes in "KRunner"-namespace
  * Fix flickering in Application Launcher for every character typed (kde#423161)
  * Port to KDEDeprecationSettings cmake function
  * KF5RunnerConfig.cmake.in: Explicitly require QtGui and KCoreAddons,
    exclude Plasma on deprecation free builds
  * Add compatibility type definitions for classes without 'Plasma' namespace
  * Fixups for building without including KService/KIO/Plasma-Frameworks (kde#447908)
  * Silence deprecation warning for KPluginInfo/KServiceTypeTrader in compatibility blocks
* Mon Jan  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.90.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.90.0
- Changes since 5.89.0:
  * Change the build system to enable building with Qt6
  * Do not require Plasma when building without deprecations
  * Improve QRegularExpression usage a bit
  * dbusrunner: Reduce unnecessary QMap lookups
  * dbusrunner: Set parent for matches to the current runner
  * Allow runners to opt-out storage of entry to history
  * RunerContext: Allow runners to update the query string
* Sat Dec  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.89.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.89.0
- Changes since 5.88.0:
  * Port to KPluginMetaData::isEnabled instead of custom string magic
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Strip 'Source' URL for faster submissions
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.88.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.88.0
- Changes since 5.87.0:
  * Deprecate K_EXPORT_PLASMA_RUNNER_WITH_JSON macro in favor or K_PLUGIN_CLASS_WITH_JSON
  * Deprecate RunnerManager::allowedRunners method
  * Add FreeBSD CI
* Sun Oct  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.87.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.87.0
- Too many changes to list here.
* Wed Sep 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unneeded baselibs.conf.
* Mon Sep  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.86.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.86.0
- Changes since 5.85.0:
  * replace "MacOSX" with "macOS"
  * Port away from KPluginLoader
  * Output warning if unknown X-Plasma-API is requested
  * Deprecate constructor overload which can not be used with KPluginFactory
  * cmake: Remove intermediate copy target
  * Use the pointer-to-member-function QObject::connect() signal/slot syntax
  * Add snippet on how to port deprecated AbstractRunner action methods
  * abstractrunner: Deprecate utility methods for actions
  * dbusrunner: Add Teardown and Config methods to D-Bus interface
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.85.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.85.0
- Changes since 5.84.0:
  * Deprecate RunnerManager::runnerMetaDataList(QString parentApp) method
  * Deprecate TryExec property for runners
  * Use KFileUtils::findAllUniqueFiles to locate DBus runners
  * Port away from deprecated QMutex constructor
* Sun Jul  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.84.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.84.0
- Changes since 5.83.0:
  * Unify how d-pointer is created
  * Remove obsolete K_EXPORT_PLUGIN_VERSION usages
  * Remve defunct X-Plasma-Args from service type file
- Only install the license files once
* Sat Jun  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.83.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.83.0
- Changes since 5.82.0:
  * runnermanager: Remove unneeded version check
  * Bump required CMake version to 3.16
  * RunnerManager::runnerMetaDataList: Do not return duplicate plugin IDs
* Sat May  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.82.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.82.0
- Too many changes since 5.81.0, only listing bugfixes:
  * Allow runners to prevent duplicate results (kde#406292)
  * runnermanager: Allow loading runners in single runner mode if
    they are disabled (kde#435050)
  * dbus runner: Fix interface definition (kde#433549)
* Mon Apr  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.81.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.81.0
- Changes since 5.80.0:
  * autotests: Add tests for RunnerManager history functionality
  * Deprecate concept of delayed runners & related methods
  * Deprecate methods to remove matches in RunnerContext
* Sun Mar  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.80.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.80.0
- Changes since 5.79.0:
  * Add pre-commit hook for clang-format
  * Add .git-blame-ignore-revs file
  * Run clang-format
  * Simplify SingleRunnerMode code
  * autotests: Use new test utilities in dbus runner test
  * Add header and CMake configuration to help writing tests
  * autotests: Add assert if service and object from runner are successfully registered
* Mon Feb  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.79.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.79.0
- Changes since 5.78.0:
  * Add .vscode to .gitignore file
  * Check for selected action in case of informational match
  * Fix empty result string for current activity
  * Deprecate overloads for QueryMatch ids
  * [DBus Runner] Test RemoteImage
* Wed Jan  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.78.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.78.0
- Too many changes to list here.
* Mon Dec  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.77.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.77.0
- Changes since 5.76.0:
  * Do not use explicitly deleted constructor in autotests
  * Deprecate KDE4 package remnants
  * Remove unneeded test
  * Use isValid() method instead of nullptr check
  * Simplify nullptr checks
  * Make use of new KPluginMetaData plugin constructor support of KPluginLoader
  * Add trailing commas
  * Add clang-format target
  * Rework internals of match id methods and add tests for it
* Sat Nov  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Too many changes to list here.
* Mon Oct  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- Too many changes to list here.
* Sun Sep  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- Changes since 5.73.0:
  * Add template for python runner
  * Use Q_DECLARE_OPERATORS_FOR_FLAGS in same namespace as flags definition
  * Update template for KDE Store compatibility and improve README
  * Remove obsolete COPYING files
  * Add support for runner syntaxes to dbus runners
  * KRunner: Convert copyright statements to SPDX expressions
  * Fix some clazy warnings
  * Save RunnerContext after each match session
  * Remove dead debug code
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Changes since 5.72.0:
  * Remove unused forward declaration
  * Implement KConfig watcher for enabled plugins and runner KCMs
  * Do not remove virtual method from build (kde#423003)
  * Deprecate AbstractRunner::dataEngine(...)
  * Fix disabled runners and runner config for plasmoid
  * Use KF-standardized Qt logging categories
  * Delay emitting metadata porting warnings until KF 5.75
- Drop krunner/0001-Do-not-remove-virtual-method-from-build.patch
  * Merged upstream.
* Tue Jul 14 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix ABI mismatch (kde#423003):
  * 0001-Do-not-remove-virtual-method-from-build.patch
* Sun Jul  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- Changes since 5.71.0:
  * Fix RunnerContextTest to not assume presence of .bashrc
  * Use embedded JSON metadata for binary plugins & custom for D-Bus plugins
  * Emit queryFinished when all jobs for current query have finished (kde#422579)
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- Changes since 5.70.0:
  * Fix and expand unit test
  * Do not persist runner whitelist to config
  * KRunner fix prepare/teardown signals (kde#420311)
  * Improve docstring for Type::InformationalMatch
  * Detect local files and folders starting with ~
  * Deprecate defunct functions
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- Changes since 5.69.0:
  * DBus Runner: Add service property to request actions once
  * Print a warning if runner is incompatible with KRunner
  * KRunner: Improve code snippet
  * Use ecm_setup_qtplugin_macro_names
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- No code change since 5.68.0
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * templates: Convert license statements to SPDX headers
  * Use ecm_qt_install_logging_categories over manual categories file
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- Changes since 5.66.0:
  * Port QRegExp to QRegularExpression
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * Update the obsolete projects.kde.org URL
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Changes since 5.64.0:
  * Use ECMGenerateExportHeader to manage deprecated API better
  * Include KDE CMake settings macros as first
  * KRunner: port away from deprecated KF5 API
  * Remove unused variable "package"
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- No code change since 5.63.0
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Changes since 5.62.0:
  * Consider UNC paths as NetworkShare context
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * Make sure we're checking whether tearing down is due after finishing a job
  * Port runnertest to QGuiApplication
  * Fix runnertest exiting early
  * Add a done signal to FindMatchesJob instead of using QObjectDecorator wrongly
  * Remove unused includes
- Replace foo-devel with cmake(KF5Foo) in build requirements
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- No code change since 5.60.0
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * Don't delay emission of matchesChanged indefinitely
  * Install in new logging directory when we use kf5 5.59.0
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- No code changes since 5.58.0
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- No code changes since 5.57.0
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * [krunners] compile without foreach
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * It compiles fine without deprecated methods
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * Remove explicit use of ECM_KDE_MODULE_DIR, is part of ECM_MODULE_PATH
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * Fix warning + port to for(...:...)
  * Fix compare float
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Use isEmpty()
  * When re-using runners when reloading, reload their configuration (kde#399621)
  * It compiles fine without deprecated method
  * Remove extra ;
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Use new syntax
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * Add strict compile flags
  * Use QStringLiteral here
  * Avoid potential detach on range-loops with non-const Qt containers
  * API dox: 0 -> nullptr
  * Use directly KDEFrameworkCompilerSettings and clean up
  * Remove extra ;
  * Make it compiles with strict compile flags
  * Fix minor EBN issues
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * autotests: ensure Plasma/Runner servicetype is found in CI
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * Honor BUILD_TESTING
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * None
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Process DBus replies in the ::match thread (kde#394272)
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * DBus runner servicename wildcard support
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * cleanup test files
  * Use nullptr/override/static_cast<...>
  * Remove not necessary QtCore and co
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * Update krunner plugin template
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * None
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Remove obsolete reviewboardrc file
  * Prevent cmake 3.10+ warning with moc & K_EXPORT_PLASMA_RUNNER/RUNNER_CONFIG"
  * Remove unneeded moc include
  * [RunnerManager] Don't mess with ThreadWeaver thread count
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Fix some clazy wrning
  * Autogenerate it too
  * Remove unused include
  * Port to autogenerated category file
  * KRunner template: remove bogus translation strings
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * None
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * drop examples dir
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * Clear previous actions on update
  * Use QUrls from match to create mimeData in base implementation
  * Add remote runners over DBus
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * API dox: use official name "D-Bus"
  * Use more nullptr
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * Add missing Q_OBJECT macro
  * Add arcconfig
  * cmake: use ecm_add_tests
  * [FEATURE] Option to build & install QCH file with the public API dox
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * Use explicit flag value instead of nullptr
  * API dox: fix note of CamelCase includes, now prefixed with KRunner
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Template: Change toplevel template category to "Plasma"
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * Upgrade KF5 version to 5.33.0.
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Commit translations from l10n-kf5
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Upgrade KF5 version to 5.32.0.
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * i18n: handle strings in kdevtemplate files
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * [QueryMatch] Add iconName
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * Fix metainfo.yaml: KRunner is neither a porting aid nor deprecated
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Import runner template from KAppTemplate
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * RunnerManager: Simplify plugin loading code
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * Do not detect anything with a '.' as a NetworkLocation
    (kde#340140)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
* Sat Dec  6 2014 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * Add a simple cli tool to run a query on all runners
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.5.0.php
* Sun Nov  2 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.4.0.php
* Sat Oct  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.3.0.php
* Tue Sep  9 2014 hrvoje.senjan@gmail.com
- Update to 5.2.0
  * For more details please see:
    http://kde.org/announcements/kde-frameworks-5.2.php
* Sat Aug  2 2014 hrvoje.senjan@gmail.com
- Update to 5.1.0
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.1.php
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Define kf5_version within package
* Tue Jul  1 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Final release of KDE Frameworks 5
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.0.php
* Sun Jun  1 2014 hrvoje.senjan@gmail.com
- Update to 4.100.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta3.php
- Add baselibs.conf
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Update to 4.99.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta2.php
* Sat Mar 29 2014 hrvoje.senjan@gmail.com
- Activate KRunner package
